@@ -1,7 +1,9 @@
 import logging
 import os
+import sys
 
-version_info = (0, 1, 0)
+
+version_info = (0, 3, 1)
 __version__ = ".".join(map(str, version_info))
 
 
@@ -10,8 +12,8 @@ logger = logging.getLogger('circus')
 
 def get_arbiter(watchers, controller='tcp://127.0.0.1:5555',
                 pubsub_endpoint='tcp://127.0.0.1:5556',
-                env=None, name=None, context=None,
-                check_flapping=True, background=False):
+                env=None, name=None, context=None, check_flapping=True,
+                background=False, stream_backend="thread"):
     """Creates a Arbiter and a single watcher in it.
 
     Options:
@@ -22,7 +24,7 @@ def get_arbiter(watchers, controller='tcp://127.0.0.1:5555',
         - **name** -- the name of the watcher (default: None)
         - **cmd** -- the command line used to run the Watcher.
         - **args** -- the args for the command (list or string).
-        - **executable**: When executable is given, the first item in
+        - **executable** -- When executable is given, the first item in
           the args sequence obtained from **cmd** is still treated by most
           programs as the command name, which can then be different from the
           actual executable name. It becomes the display name for the executing
@@ -36,6 +38,20 @@ def get_arbiter(watchers, controller='tcp://127.0.0.1:5555',
         - **uid** -- the user id used to run the flies (default: None)
         - **gid** -- the group id used to run the flies (default: None)
         - **env** -- the environment passed to the flies (default: None)
+        - **stdout_stream**: a mapping containing the options for configuring
+          the stdout stream. Default to None. When provided, may contain:
+            - **class**: the fully qualified name of the class to use for
+              streaming. Defaults to circus.stream.FileStream
+            - **refresh_time**: the delay between two stream checks. Defaults to
+              0.3 seconds.
+            - any other key will be passed the class constructor.
+        - **stderr_stream**: a mapping containing the options for configuring
+          the stderr stream. Default to None. When provided, may contain:
+            - **class**: the fully qualified name of the class to use for
+              streaming. Defaults to circus.stream.FileStream
+            - **refresh_time**: the delay between two stream checks. Defaults to
+              0.3 seconds.
+            - any other key will be passed the class constructor.
 
     - **controller** -- the zmq entry point (default: 'tcp://127.0.0.1:5555')
     - **pubsub_endpoint** -- the zmq entry point for the pubsub
@@ -45,7 +61,25 @@ def get_arbiter(watchers, controller='tcp://127.0.0.1:5555',
       (default:True)
     - **background** -- If True, the arbiter is launched in a thread in the
       background (default: False)
+    - **stream_backend** -- the backend that will be used for the streaming
+      process. Can be *thread* or *gevent*. When set to *gevent* you need
+      to have *gevent* and *gevent_zmq* installed. (default: thread)
     """
+    if stream_backend == 'gevent':
+        try:
+            import gevent           # NOQA
+            import gevent_zeromq    # NOQA
+        except ImportError:
+            sys.stderr.write("stream_backend set to gevent, " +
+                             "but gevent or gevent_zeromq isn't installed\n")
+            sys.stderr.write("Exiting...")
+            sys.exit(1)
+
+        from gevent import monkey
+        from gevent_zeromq import monkey_patch
+        monkey.patch_all()
+        monkey_patch()
+
     from circus.watcher import Watcher
     if background:
         from circus.arbiter import ThreadedArbiter as Arbiter   # NOQA
@@ -56,20 +90,9 @@ def get_arbiter(watchers, controller='tcp://127.0.0.1:5555',
 
     for watcher in watchers:
         cmd = watcher['cmd']
-        name = watcher.get('name', os.path.basename(cmd.split()[0]))
-
-        watcher = Watcher(name,
-                          cmd,
-                          args=watcher.get('args'),
-                          numprocesses=watcher.get('numprocesses', 1),
-                          working_dir=watcher.get('working_dir'),
-                          warmup_delay=float(watcher.get('warmup_delay', '0')),
-                          shell=watcher.get('shell'),
-                          uid=watcher.get('uid'),
-                          gid=watcher.get('gid'),
-                          env=watcher.get('env'),
-                          executable=watcher.get('executable'))
-        _watchers.append(watcher)
+        watcher['name'] = watcher.get('name', os.path.basename(cmd.split()[0]))
+        watcher['stream_backend'] = stream_backend
+        _watchers.append(Watcher.load_from_config(watcher))
 
     return Arbiter(_watchers, controller, pubsub_endpoint, context=context,
                    check_flapping=check_flapping)
