@@ -11,7 +11,8 @@ from circus.exc import AlreadyExist
 from circus.flapping import Flapping
 from circus import logger
 from circus.watcher import Watcher
-from circus.util import debuglog
+from circus.util import debuglog, _setproctitle
+from circus.config import get_config
 
 
 class Arbiter(object):
@@ -19,12 +20,19 @@ class Arbiter(object):
 
     Options:
 
-    - **watchers**: a list of Watcher objects
-    - **endpoint**: the controller ZMQ endpoint
-    - **pubsub_endpoint**: the pubsub endpoint
-    - **check_delay**: the delay between two controller points (default: 1 s)
-    - **prereload_fn**: callable that will be executed on each reload
+    - **watchers** -- a list of Watcher objects
+    - **endpoint** -- the controller ZMQ endpoint
+    - **pubsub_endpoint** -- the pubsub endpoint
+    - **check_delay** -- the delay between two controller points
+      (default: 1 s)
+    - **prereload_fn** -- callable that will be executed on each reload
       (default: None)
+    - **context** -- if provided, the zmq context to reuse.
+      (default: None)
+    - **loop**: if provided, a :class:`zmq.eventloop.ioloop.IOLoop` instance
+       to reuse. (default: None)
+    - **check_flapping** -- when True, Circus will check for flapping
+      processes and automatically restart them. (default: True)
     """
     def __init__(self, watchers, endpoint, pubsub_endpoint, check_delay=1.,
                  prereload_fn=None, context=None, loop=None,
@@ -47,8 +55,29 @@ class Arbiter(object):
         self.busy = False
         self.check_flapping = check_flapping
 
+    @classmethod
+    def load_from_config(cls, config_file):
+        cfg = get_config(config_file)
+
+        # hack reload ioloop to use the monkey patched version
+        reload(ioloop)
+
+        watchers = []
+        for watcher in cfg.get('watchers', []):
+            watchers.append(Watcher.load_from_config(watcher))
+
+        # creating arbiter
+        arbiter = cls(watchers, cfg['endpoint'], cfg['pubsub_endpoint'],
+                      check_delay=cfg.get('check_delay', 1.),
+                      prereload_fn=cfg.get('prereload_fn'))
+
+        return arbiter
+
     @debuglog
     def initialize(self):
+        # set process title
+        _setproctitle("circusd")
+
         # event pub socket
         self.evpub_socket = self.context.socket(zmq.PUB)
         self.evpub_socket.bind(self.pubsub_endpoint)
@@ -107,9 +136,9 @@ class Arbiter(object):
         self.ctrl.stop()
         self.evpub_socket.close()
 
-    def stop(self, graceful=False):
+    def stop(self):
         if self.alive:
-            self.stop_watchers(graceful=graceful, stop_alive=True)
+            self.stop_watchers(stop_alive=True)
         self.loop.stop()
 
     def manage_watchers(self):
@@ -206,16 +235,16 @@ class Arbiter(object):
         for watcher in self.watchers:
             watcher.start()
 
-    def stop_watchers(self, graceful=True, stop_alive=False):
+    def stop_watchers(self, stop_alive=False):
+        if not self.alive:
+            return
+
         if stop_alive:
             logger.info('Arbiter exiting')
-            if not self.alive:
-                return
-
             self.alive = False
 
         for watcher in self.watchers:
-            watcher.stop(graceful=graceful)
+            watcher.stop()
 
 
 class ThreadedArbiter(Arbiter, Thread):
