@@ -7,7 +7,6 @@ class Stop(Command):
         =============================
 
         This command stop all the process in a watcher or all watchers.
-        The watchers can be stopped gracefully.
 
         ZMQ Message
         -----------
@@ -18,12 +17,10 @@ class Stop(Command):
                 "command": "stop",
                 "propeties": {
                     "name": '<name>",
-                    "graceful": true
                 }
             }
 
-        The response return the status "ok". If the property graceful is
-        set to true the processes will be exited gracefully.
+        The response return the status "ok".
 
         If the property name is present, then the reload will be applied
         to the watcher.
@@ -34,29 +31,23 @@ class Stop(Command):
 
         ::
 
-            $ circusctl reload [<name>] [--terminate]
+            $ circusctl reload [<name>]
 
         Options
         +++++++
 
         - <name>: name of the watcher
-        - --terminate; quit the node immediately
 
     """
 
     name = "stop"
-    options = [('', 'terminate', False, "stop immediately")]
 
     def message(self, *args, **opts):
-        graceful = not opts.get("terminate", False)
-        if len(args) == 1:
-            return self.make_message(name=args[0], graceful=graceful)
-
-        return self.make_message(graceful=graceful)
+        return self.make_message()
 
     def execute(self, arbiter, props):
         if 'name' in props:
             watcher = self._get_watcher(arbiter, props['name'])
-            watcher.stop(graceful=props.get('graceful', True))
+            watcher.stop()
         else:
-            arbiter.stop_watchers(graceful=props.get('graceful', True))
+            arbiter.stop_watchers()
