@@ -1,12 +1,23 @@
-import unittest
-import os
 import sys
-import tempfile
 import time
+
 from circus.process import Process, RUNNING
+from circus.tests.support import TestCircus
 
 
-class TestProcess(unittest.TestCase):
+RLIMIT = '''\
+import resource, sys
+
+f = open(sys.argv[1], 'w')
+for limit in ('NOFILE', 'NPROC'):
+    res = getattr(resource, 'RLIMIT_%s' % limit)
+    f.write('%s=%s\\n' % (limit, resource.getrlimit(res)))
+
+f.close
+'''
+
+
+class TestProcess(TestCircus):
 
     def test_base(self):
         cmd = sys.executable
@@ -22,24 +33,14 @@ class TestProcess(unittest.TestCase):
             process.stop()
 
     def test_rlimits(self):
-        script_file = tempfile.mkstemp()[1]
-        output_file = tempfile.mkstemp()[1]
-        script = '''
-import resource, sys
-f = open(sys.argv[1], 'w')
-for limit in ('NOFILE', 'NPROC'):
-    res = getattr(resource, 'RLIMIT_%s' % limit)
-    f.write('%s=%s\\n' % (limit, resource.getrlimit(res)))
-f.close
-        '''
-        f = open(script_file, 'w')
-        f.write(script)
-        f.close()
+        script_file = self.get_tmpfile(RLIMIT)
+        output_file = self.get_tmpfile()
+
         cmd = sys.executable
         args = [script_file, output_file]
         rlimits = {'nofile': 20,
-                   'nproc': 20,
-                  }
+                   'nproc': 20}
+
         process = Process('test', cmd, args=args, rlimits=rlimits)
         # wait for the process to finish
         while process.status == RUNNING:
@@ -48,7 +49,7 @@ f.close
         f = open(output_file, 'r')
         output = {}
         for line in f.readlines():
-            (limit, value) = line.rstrip().split('=', 1)
+            limit, value = line.rstrip().split('=', 1)
             output[limit] = value
         f.close()
 
@@ -56,9 +57,6 @@ f.close
             return [long(key) for key in val[1:-1].split(',')]
 
         wanted = [20L, 20L]
-        try:
-            self.assertEqual(srt2ints(output['NOFILE']), wanted)
-            self.assertEqual(srt2ints(output['NPROC']), wanted)
-        finally:
-            os.unlink(script_file)
-            os.unlink(output_file)
+
+        self.assertEqual(srt2ints(output['NOFILE']), wanted)
+        self.assertEqual(srt2ints(output['NPROC']), wanted)
