@@ -1,33 +1,63 @@
-import ConfigParser
 from datetime import timedelta
 import grp
 import os
 import pwd
 import fcntl
-import fnmatch
 from functools import wraps
+import sys
+import shlex
 
 from psutil.error import AccessDenied, NoSuchProcess
 from circus import logger
 
 
+try:
+    from importlib import import_module         # NOQA
+except ImportError:
+    def _resolve_name(name, package, level):
+        """Returns the absolute name of the module to be imported. """
+        if not hasattr(package, 'rindex'):
+            raise ValueError("'package' not set to a string")
+        dot = len(package)
+        for x in xrange(level, 1, -1):
+            try:
+                dot = package.rindex('.', 0, dot)
+            except ValueError:
+                raise ValueError("attempted relative import beyond top-level "
+                                  "package")
+        return "%s.%s" % (package[:dot], name)
+
+
+    def import_module(name, package=None):      # NOQA
+        """Import a module.
+        The 'package' argument is required when performing a relative import.
+        It specifies the package to use as the anchor point from which to
+        resolve the relative import to an absolute import."""
+        if name.startswith('.'):
+            if not package:
+                raise TypeError("relative imports require the 'package' "
+                                "argument")
+            level = 0
+            for character in name:
+                if character != '.':
+                    break
+                level += 1
+            name = _resolve_name(name[level:], package, level)
+        __import__(name)
+        return sys.modules[name]
+
+try:
+    from setproctitle import setproctitle
+    def _setproctitle(title):       # NOQA
+        setproctitle(title)
+except ImportError:
+    def _setproctitle(title):       # NOQA
+        return
+
+
 _SYMBOLS = ('K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y')
 
 
-class DefaultConfigParser(ConfigParser.ConfigParser):
-    def dget(self, section, option, default=None, type=str):
-        if not self.has_option(section, option):
-            return default
-        if type is str:
-            return self.get(section, option)
-        elif type is int:
-            return self.getint(section, option)
-        elif type is bool:
-            return self.getboolean(section, option)
-        else:
-            raise NotImplementedError()
-
-
 def get_working_dir():
     """Returns current path, try to use PWD env first"""
     try:
@@ -107,7 +137,7 @@ def get_info(process):
         info['nice'] = 'Zombie'
 
     try:
-        cmdline = os.path.basename(process.cmdline[0])
+        cmdline = os.path.basename(shlex.split(process.cmdline[0])[0])
     except (AccessDenied, IndexError):
         cmdline = "N/A"
 
@@ -216,23 +246,44 @@ def convert_opt(key, val):
     return val
 
 
-def read_config(config_path):
-    cfg = DefaultConfigParser()
-    with open(config_path) as f:
-        cfg.readfp(f)
-    cfg_files_read = [config_path]
+# taken from distutils2
+def resolve_name(name):
+    """Resolve a name like ``module.object`` to an object and return it.
 
-    # load included config files
-    includes = []
-    for include_file in cfg.dget('circus', 'include', '').split():
-        includes.append(include_file)
+    This functions supports packages and attributes without depth limitation:
+    ``package.package.module.class.class.function.attr`` is valid input.
+    However, looking up builtins is not directly supported: use
+    ``__builtin__.name``.
 
-    for include_dir in cfg.dget('circus', 'include_dir', '').split():
-        for root, dirnames, filenames in os.walk(include_dir):
-            for filename in fnmatch.filter(filenames, '*.ini'):
-                cfg_file = os.path.join(root, filename)
-                includes.append(cfg_file)
+    Raises ImportError if importing the module fails or if one requested
+    attribute is not found.
+    """
+    if '.' not in name:
+        # shortcut
+        __import__(name)
+        return sys.modules[name]
 
-    cfg_files_read.extend(cfg.read(includes))
+    # FIXME clean up this code!
+    parts = name.split('.')
+    cursor = len(parts)
+    module_name = parts[:cursor]
+    ret = ''
 
-    return cfg, cfg_files_read
+    while cursor > 0:
+        try:
+            ret = __import__('.'.join(module_name))
+            break
+        except ImportError:
+            cursor -= 1
+            module_name = parts[:cursor]
+
+    if ret == '':
+        raise ImportError(parts[0])
+
+    for part in parts[1:]:
+        try:
+            ret = getattr(ret, part)
+        except AttributeError, exc:
+            raise ImportError(exc)
+
+    return ret
