@@ -7,18 +7,91 @@ from zmq.utils.jsonapi import jsonmod as json
 from circus.process import Process, DEAD_OR_ZOMBIE
 from circus import logger
 from circus import util
+from circus.stream import get_pipe_redirector
 
 
 class Watcher(object):
+    """
+    Class managing a list of processes for a given command.
 
+    Options:
+
+    - **name**: name given to the watcher. Used to uniquely identify it.
+
+    - **cmd**: the command to run. May contain *$WID*, which will be
+      replaced by **wid**.
+
+    - **args**: the arguments for the command to run. Can be a list or
+      a string. If **args** is  a string, it's splitted using
+      :func:`shlex.split`. Defaults to None.
+
+    - **numprocesses**: Number of processes to run.
+
+    - **working_dir**: the working directory to run the command in. If
+      not provided, will default to the current working directory.
+
+    - **shell**: if *True*, will run the command in the shell
+      environment. *False* by default. **warning: this is a
+      security hazard**.
+
+    - **uid**: if given, is the user id or name the command should run
+      with. The current uid is the default.
+
+    - **gid**: if given, is the group id or name the command should run
+      with. The current gid is the default.
+
+    - **env**: a mapping containing the environment variables the command
+      will run with. Optional.
+
+    - **rlimits**: a mapping containing rlimit names and values that will
+      be set before the command runs.
+
+    - **stdout_stream**: a callable that will receive the stream of
+      the process stdout. Defaults to None.
+
+      When provided, *stdout_stream* is a mapping containing two keys:
+
+      - **stream**: the callable that will receive the updates
+        streaming. Defaults to :class:`circus.stream.FileStream`
+
+      - **refresh_time**: the delay between two stream checks. Defaults
+        to 0.3 seconds.
+
+      Each entry received by the callable is a mapping containing:
+
+      - **pid** - the process pid
+      - **name** - the stream name (*stderr* or *stdout*)
+      - **data** - the data
+
+    - **stderr_stream**: a callable that will receive the stream of
+      the process stderr. Defaults to None.
+
+      When provided, *stdout_stream* is a mapping containing two keys:
+
+      - **stream**: the callable that will receive the updates
+        streaming. Defaults to :class:`circus.stream.FileStream`
+
+      - **refresh_time**: the delay between two stream checks. Defaults
+        to 0.3 seconds.
+
+      Each entry received by the callable is a mapping containing:
+
+      - **pid** - the process pid
+      - **name** - the stream name (*stderr* or *stdout*)
+      - **data** - the data
+
+    - **stream_backend** -- the backend that will be used for the streaming
+      process. Can be *thread* or *gevent*. When set to *gevent* you need
+      to have *gevent* and *gevent_zmq* installed. (default: thread)
+
+    """
     def __init__(self, name, cmd, args=None, numprocesses=1, warmup_delay=0.,
                  working_dir=None, shell=False, uid=None,
                  gid=None, send_hup=False, env=None, stopped=True,
                  times=2, within=1., retry_in=7., max_retry=5,
                  graceful_timeout=30., prereload_fn=None,
-                 rlimits=None, executable=None):
-        """ init
-        """
+                 rlimits=None, executable=None, stdout_stream=None,
+                 stderr_stream=None, stream_backend='thread'):
         self.name = name
         self.res_name = name.lower().replace(" ", "_")
         self.numprocesses = int(numprocesses)
@@ -34,6 +107,21 @@ class Watcher(object):
         self.graceful_timeout = 30
         self.prereload_fn = prereload_fn
         self.executable = None
+        self.stream_backend = stream_backend
+
+        self.stdout_stream = stdout_stream
+        if stdout_stream:
+            self.stdout_redirector = get_pipe_redirector(stdout_stream,
+                    backend=stream_backend)
+        else:
+            self.stdout_redirector = None
+
+        self.stderr_stream = stderr_stream
+        if stderr_stream:
+            self.stderr_redirector = get_pipe_redirector(stderr_stream,
+                    backend=stream_backend)
+        else:
+            self.stderr_redirector = None
 
         self.optnames = ("numprocesses", "warmup_delay", "working_dir",
                          "uid", "gid", "send_hup", "shell", "env",
@@ -45,7 +133,6 @@ class Watcher(object):
             working_dir = util.get_working_dir()
 
         self.working_dir = working_dir
-
         self.processes = {}
         self.shell = shell
         self.uid = uid
@@ -55,6 +142,32 @@ class Watcher(object):
         self.send_hup = send_hup
         self.evpub_socket = None
 
+    @classmethod
+    def load_from_config(cls, config):
+        return cls(name=config['name'],
+                   cmd=config['cmd'],
+                   args=config.get('args'),
+                   numprocesses=config.get('numprocesses', 1),
+                   warmup_delay=config.get('warmup_delay', 0),
+                   working_dir=config.get('working_dir'),
+                   shell=config.get('shell', False),
+                   uid=config.get('uid'),
+                   gid=config.get('gid'),
+                   send_hup=config.get('send_hup', False),
+                   env=config.get('env'),
+                   stopped=config.get('stopped', True),
+                   times=config.get('times', 2),
+                   within=config.get('within', 1),
+                   retry_in=config.get('retry_in', 7),
+                   max_retry=config.get('max_retry', 5),
+                   graceful_timeout=config.get('graceful_timeout', 30),
+                   prereload_fn=config.get('prereload_fn'),
+                   rlimits=config.get('rlimits'),
+                   executable=config.get('executable'),
+                   stdout_stream=config.get('stdout_stream'),
+                   stderr_stream=config.get('stderr_stream'),
+                   stream_backend=config.get('stream_backend', 'thread'))
+
     @util.debuglog
     def initialize(self, evpub_socket):
         self.evpub_socket = evpub_socket
@@ -149,6 +262,17 @@ class Watcher(object):
                           env=self.env, rlimits=self.rlimits,
                           executable=self.executable)
 
+                # stream stderr/stdout if configured
+                if self.stdout_redirector is not None:
+                    self.stdout_redirector.add_redirection('stdout',
+                                                           process,
+                                                           process.stdout)
+
+                if self.stderr_redirector is not None:
+                    self.stderr_redirector.add_redirection('stderr',
+                                                           process,
+                                                           process.stderr)
+
                 self.processes[self._process_counter] = process
                 logger.debug('running %s process [pid %d]', self.name,
                             process.pid)
@@ -170,6 +294,13 @@ class Watcher(object):
     def kill_process(self, process, sig=signal.SIGTERM):
         """Kill process.
         """
+        # remove redirections
+        if self.stdout_redirector is not None:
+            self.stdout_redirector.remove_redirection('stdout', process)
+
+        if self.stderr_redirector is not None:
+            self.stderr_redirector.remove_redirection('stderr', process)
+
         self.send_msg("kill", {"process_id": process.wid,
                                "time": time.time()})
         logger.debug("%s: kill process %s", self.name, process.pid)
@@ -235,28 +366,27 @@ class Watcher(object):
                      self.processes.items()])
 
     @util.debuglog
-    def stop(self, graceful=True):
+    def stop(self):
         """Stop.
         """
         self.stopped = True
+        # stop redirectors
+        if self.stdout_redirector is not None:
+            self.stdout_redirector.kill()
 
-        sig = signal.SIGQUIT
-        if not graceful:
-            sig = signal.SIGTERM
+        if self.stderr_redirector is not None:
+            self.stderr_redirector.kill()
 
         limit = time.time() + self.graceful_timeout
         while self.processes and time.time() < limit:
-            self.kill_processes(sig)
+            self.kill_processes(signal.SIGTERM)
             time.sleep(0.1)
-
-            # reap processes
-            for wid, process in self.processes.items():
-                if process.poll() is not None:
-                    del self.processes[wid]
+            self.reap_processes()
 
         self.kill_processes(signal.SIGKILL)
         if self.evpub_socket is not None:
             self.send_msg("stop", {"time": time.time()})
+
         logger.info('%s stopped', self.name)
 
     @util.debuglog
@@ -269,6 +399,12 @@ class Watcher(object):
         self.stopped = False
         self.reap_processes()
         self.manage_processes()
+        if self.stdout_redirector is not None:
+            self.stdout_redirector.start()
+
+        if self.stderr_redirector is not None:
+            self.stderr_redirector.start()
+
         logger.info('%s started' % self.name)
         self.send_msg("start", {"time": time.time()})
 
